@@ -1,23 +1,25 @@
 import sys
 
 import click
+import os
 
 from ProjectAliceSK.util.Helpers import OptionEatAll
 from ProjectAliceSK.validate.src.Validator import Validator
 
 
 @click.command()
-@click.option('--paths', cls=OptionEatAll, required=True, help='skill paths to test')
-@click.option('-v', '--verbose', count=True, help='verbosity to print')
+@click.option('-p', '--paths', default=None, cls=OptionEatAll, help='Paths to test')
+@click.option('-v', '--verbose', count=True, help='Verbosity level')
 def validate(paths: list, verbose: int):
 	"""
 	Validate Skills
 	"""
 
-	valid = Validator(
-		skillPaths=paths,
-		verbosity=verbose)
-	error = valid.validate()
+	if not paths:
+		paths = [os.getcwd()]
+
+	validator = Validator(skillPaths=paths, verbosity=verbose)
+	error = validator.validate()
 	sys.exit(error)
 
 
